<?php

namespace Elementor;

class TsPlayer_Widget extends Widget_Base
{

    public function get_name()
    {
        return 'tsplayer';
    }

    public function get_title()
    {
        return 'پلیر موزیک';
    }

    public function get_icon()
    {
        return 'eicon-play-o';
    }

    public function get_categories()
    {
        return ['basic'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __('تنظیمات پلیر', 'plugin-name'),
            ]
        );

        $this->add_control(
            'audio_file',
            [
                'label' => __('فایل صوتی', 'plugin-name'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => '',
                ],
            ]
        );

        $this->add_control(
            'audio_url',
            [
                'label' => __('آدرس فایل صوتی', 'plugin-name'),
                'type' => Controls_Manager::TEXT,
                'default' => '',
            ]
        );

        $this->add_control(
            'bass_boost',
            [
                'label' => __('(بتا) افزایش بیس', 'plugin-name'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 0,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mediPlayer audio' => 'filter: bassboost({{SIZE}}%);',
                ],
            ]
        );
        
        

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style',
            [
                'label' => __('استایل', 'plugin-name'),
            ]
        );

        $this->add_control(
            'play_color',
            [
                'label' => __('رنگ پلی', 'plugin-name'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .play polygon' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label' => __('رنگ حاشیه', 'plugin-name'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .progress-track' => 'stroke: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pause_color',
            [
                'label' => __('رنگ پاز', 'plugin-name'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pause line' => 'stroke: {{VALUE}};',
                ],
            ]
        );


        $this->add_control(
            'progress_color',
            [
                'label' => __('رنگ پیشرفت', 'plugin-name'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .progress-bar' => 'stroke: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'background_color',
            [
                'label' => __('رنگ بک گراند', 'plugin-name'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #playable0' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'playable0_padding',
            [
                'label' => __('اندازه', 'plugin-name'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} #playable0' => 'padding: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'playable0_border_radius',
            [
                'label' => __('خمیدگی گوشه', 'plugin-name'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} #playable0' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if (!empty($settings['audio_file']['url'])) {
            $audio_src = esc_url($settings['audio_file']['url']);
        } elseif (!empty($settings['audio_url'])) {
            $audio_src = esc_url($settings['audio_url']);
        } else {
            $audio_src = '';
        }

        if (!empty($audio_src)) {
            echo do_shortcode("[tsplayer src='$audio_src']");
        }

        static $is_script_executed = false;

        if (!$is_script_executed && \Elementor\Plugin::instance()->editor->is_edit_mode()) {
?>
            <script>
                jQuery(document).ready(function($) {
                    $(".mediPlayer").mediaPlayer();
                });
            </script>
<?php

            $is_script_executed = true;
        }
    }
}
